import { InjectionToken, Component, ElementRef, Input, Inject, Optional, NgModule } from '@angular/core';
import { NG_VALUE_ACCESSOR } from '@angular/forms';
import CodeMirror from 'codemirror';

var WA_CODEMIRROR_DEFAULTS = new InjectionToken('WA_CODEMIRROR_DEFAULTS');
var codemirrorInputOptions = [
    'mode', 'theme', 'lineNumbers', 'viewportMargin',
];
var CodemirrorComponent = /** @class */ (function () {
    function CodemirrorComponent($el, defaults) {
        this.$el = $el;
        this.onChange = function (_) { };
        this.onTouched = function () { };
        this.defaults = defaults || {};
    }
    CodemirrorComponent.prototype.ngOnInit = function () {
        var _this = this;
        var config = Object.assign({}, this.defaults);
        if (typeof this.lineNumbers !== 'undefined') {
            config.lineNumbers = this.lineNumbers;
        }
        if (typeof this.mode !== 'undefined') {
            config.mode = this.mode;
        }
        if (typeof this.theme !== 'undefined') {
            config.theme = this.theme;
        }
        if (typeof this.viewportMargin !== 'undefined') {
            config.viewportMargin = this.viewportMargin;
        }
        if (typeof this.defaultValue !== 'undefined') {
            config.value = this.defaultValue;
        }
        this.codemirror = CodeMirror(this.$el.nativeElement, config);
        this.codemirror.on('change', function (editor) {
            _this.onChange(editor.getValue());
        });
        this.codemirror.on('blur', function () {
            _this.onTouched();
        });
    };
    CodemirrorComponent.prototype.ngOnChanges = function (changes) {
        if (!this.codemirror) {
            return;
        }
        for (var option in changes) {
            if (changes.hasOwnProperty(option) && codemirrorInputOptions.indexOf(option) >= 0) {
                this.codemirror.setOption(option, changes[option].currentValue);
            }
        }
    };
    CodemirrorComponent.prototype.writeValue = function (value) {
        if (this.codemirror) {
            this.codemirror.setValue(value);
        }
        else {
            this.defaultValue = value;
        }
    };
    CodemirrorComponent.prototype.registerOnChange = function (fn) {
        this.onChange = fn;
    };
    CodemirrorComponent.prototype.registerOnTouched = function (fn) {
        this.onTouched = fn;
    };
    return CodemirrorComponent;
}());
CodemirrorComponent.decorators = [
    { type: Component, args: [{
                selector: 'wa-codemirror',
                template: '',
                providers: [
                    {
                        provide: NG_VALUE_ACCESSOR,
                        useExisting: CodemirrorComponent,
                        multi: true,
                    },
                ],
            },] },
];
CodemirrorComponent.ctorParameters = function () { return [
    { type: ElementRef, },
    { type: undefined, decorators: [{ type: Inject, args: [WA_CODEMIRROR_DEFAULTS,] }, { type: Optional },] },
]; };
CodemirrorComponent.propDecorators = {
    "mode": [{ type: Input },],
    "theme": [{ type: Input },],
    "lineNumbers": [{ type: Input },],
    "viewportMargin": [{ type: Input },],
};
var CodemirrorModule = /** @class */ (function () {
    function CodemirrorModule() {
    }
    return CodemirrorModule;
}());
CodemirrorModule.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    CodemirrorComponent,
                ],
                exports: [
                    CodemirrorComponent,
                ],
            },] },
];

export { CodemirrorComponent, CodemirrorModule, WA_CODEMIRROR_DEFAULTS };
//# sourceMappingURL=webacad-ng-codemirror.js.map
